from distutils.core import setup #import setup function

setup(
    name='lingu_nester',
    version='1.2.0',
    py_modules=['nester'],
    author='LinGuang',
    author_email='linguang@zju.edu.cn',
    url='http://nnnnnnn',
    description='A simple printer of nested lists'

)